==> haskell-http-download-0.2.1.0-315-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-http-download.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-download
version:              0.2.1.0
visibility:           public
id:                   http-download-0.2.1.0-G0yHsgdldNA60pzVBLIpSP
key:                  http-download-0.2.1.0-G0yHsgdldNA60pzVBLIpSP
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/http-download#readme
synopsis:             Verified downloads with retries
description:
    Higher level HTTP download APIs include verification of content and retries

category:             Development
abi:                  4e9d153d8426a62c87610a4dff7ec2ad
exposed:              True
exposed-modules:      Network.HTTP.Download Network.HTTP.Download.Verified
hidden-modules:       Paths_http_download
import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-download-0.2.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-download-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-download-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-download
hs-libraries:         HShttp-download-0.2.1.0-G0yHsgdldNA60pzVBLIpSP
depends:
    base-4.18.2.1 base64-bytestring-1.2.1.0-DIdtXjiFLF0sICzGCxvgr
    bytestring-0.11.5.3 conduit-1.3.6.1-252yfbtdylIFaQqQ0JKO9q
    conduit-extra-1.3.8-E4AHXAfmerjKj7JfHrF3lm
    crypton-1.0.4-11gen3PFWz54w2m32bVEwY
    crypton-conduit-0.2.3-FnO5Go5ATj49Ps0lmSQM1F directory-1.3.8.5
    exceptions-0.10.7 filepath-1.4.300.1
    http-client-0.7.19-ITPZXASBEGHLmOi4NfdGY8
    http-conduit-2.3.9.1-HKTEHoMQbVODlt9daK23ia
    http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    path-0.9.6-7b6FXKI3CMdJjRU7VALKqo
    path-io-1.8.2-Jhknddu9AtCK2EGLcU8uTt
    retry-0.9.3.1-HEvs5AQWwJi8IsgEJKYYst
    rio-0.1.22.0-2S3DgnoH0cl6ZJdvxjSsI5
    rio-prettyprint-0.1.8.0-IatOwnHVZpLBD126SHPF3E

haddock-interfaces:
    /usr/share/doc/haskell-http-download/html/http-download.haddock

haddock-html:         /usr/share/doc/haskell-http-download/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-download-0.2.1.0-317-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-http-download.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-download
version:              0.2.1.0
visibility:           public
id:                   http-download-0.2.1.0-AKq2NKBxRMyCC593Obud3e
key:                  http-download-0.2.1.0-AKq2NKBxRMyCC593Obud3e
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/http-download#readme
synopsis:             Verified downloads with retries
description:
    Higher level HTTP download APIs include verification of content and retries

category:             Development
abi:                  6ebf53e7ca533527816652a28fff6832
exposed:              True
exposed-modules:      Network.HTTP.Download Network.HTTP.Download.Verified
hidden-modules:       Paths_http_download
import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-download-0.2.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-download-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-download-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-download
hs-libraries:         HShttp-download-0.2.1.0-AKq2NKBxRMyCC593Obud3e
depends:
    base-4.18.2.1 base64-bytestring-1.2.1.0-AZbYiNuTo1lLfA6t4c9Fhh
    bytestring-0.11.5.3 conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh
    conduit-extra-1.3.8-Dg42smPzbiF4Nemzj9bTg6
    crypton-1.0.4-8iIZddQo7Y8B1JLRcnCUbI
    crypton-conduit-0.2.3-3EN5zse1H5T29qz3O5MqJq directory-1.3.8.5
    exceptions-0.10.7 filepath-1.4.300.1
    http-client-0.7.19-9XP2fRtq348Edv4XKGE8tD
    http-conduit-2.3.9.1-4fv8UoY8zTlKlPGaK7tn4g
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    path-0.9.6-JZJSfxZgLNX9Y539GdP67P
    path-io-1.8.2-CWPMy5Meh3QEKkmaY17vKO
    retry-0.9.3.1-FYTMxXzp6ILABIm5Dm7RjL
    rio-0.1.22.0-9YWPFaDDA8QAvZjRU1ibSo
    rio-prettyprint-0.1.8.0-1E5SvMAHYizIzsYMRS3OM

haddock-interfaces:
    /usr/share/doc/haskell-http-download/html/http-download.haddock

haddock-html:         /usr/share/doc/haskell-http-download/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
